# WinTmp

This is a python module used to getting temperatures of the cpu and gpu in windows. If this module doesn't work, make sure to open an issue!

This module also need to be run as Administrator.

Install:
`pip install WinTmp`

In admin command prompt type `python`.
Demo:

```python
>>> import WinTmp
>>> print(WinTmp.CPU_Temp())
38.0
>>> print(WinTmp.GPU_Temp())
35.0
>>>
```

PyPI page here: https://pypi.org/project/WinTmp/

Github Page Here: https://github.com/kethan1/WinTmp/
